@@ -1,5 +1,5 @@
 package DBIx::Lite;
-$DBIx::Lite::VERSION = '0.29';
+$DBIx::Lite::VERSION = '0.30';
 # ABSTRACT: Chained and minimal ORM
 use strict;
 use warnings;
@@ -42,6 +42,7 @@ sub connect {
     
     $self->{connector} = DBIx::Connector->new(@_);
     $self->{dbh} = undef;
+    $self->dbh(1) or return undef;
     $self->dbh->{HandleError} = sub { croak $_[0] };
     
     $self;
@@ -72,8 +73,10 @@ sub dbh {
     my $self = shift;
     my ($dont_die) = @_;
     
-    return $self->{dbh} ? $self->{dbh}
+    my $dbh = $self->{dbh} ? $self->{dbh}
         : $self->{connector} ? $self->{connector}->dbh
+        : undef;
+    return $dbh ? $dbh
         : $dont_die ? undef
         : croak "No database handle or DBIx::Connector object provided";
 }
@@ -150,7 +153,7 @@ DBIx::Lite - Chained and minimal ORM
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 SYNOPSIS
 
@@ -326,7 +329,7 @@ Alessandro Ranellucci <aar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Alessandro Ranellucci.
+This software is copyright (c) 2017 by Alessandro Ranellucci.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
