@@ -1,5 +1,5 @@
 package DBIx::Lite::ResultSet;
-$DBIx::Lite::ResultSet::VERSION = '0.29';
+$DBIx::Lite::ResultSet::VERSION = '0.30';
 use strict;
 use warnings;
 
@@ -28,7 +28,7 @@ sub _new {
     
     # optional arguments
     for (grep exists($params{$_}), qw(joins where select group_by having order_by
-        limit offset for_update rows_per_page page cur_table)) {
+        limit offset for rows_per_page page cur_table)) {
         $self->{$_} = delete $params{$_};
     }
     $self->{cur_table} //= $self->{table};
@@ -61,8 +61,14 @@ for my $methname (qw(group_by having order_by limit offset rows_per_page page))
 sub for_update {
     my ($self) = @_;
     
+    return $self->for('UPDATE');
+}
+
+sub for {
+    my ($self, $for) = @_;
+    
     my $new_self = $self->_clone;
-    $new_self->{for_update} = 1;
+    $new_self->{for} = $for;
     $new_self;
 }
 
@@ -224,8 +230,8 @@ sub select_sql {
         $self->{offset}     ? (-offset      => $self->{offset})     : (),
     );
     
-    if ($self->{for_update}) {
-        $sql .= " FOR UPDATE";
+    if ($self->{for}) {
+        $sql .= " FOR " . $self->{for};
     }
     
     return ($sql, @bind);
@@ -672,7 +678,7 @@ DBIx::Lite::ResultSet
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 OVERVIEW
 
@@ -795,6 +801,17 @@ L<all()> or L<next()>.
         $author->update({ age => 30 });
     });
 
+This is actually a shortcut for the L<for> method described below:
+
+    my $authors = $dbix->table('authors')->for('UPDATE');
+
+=head2 for
+
+This method accepts a string which will be appended to the C<FOR> keyword at the end
+of the SQL query.
+
+    my $authors = $dbix->table('authors')->for('UPDATE SKIP LOCKED');
+
 =head2 inner_join
 
 This method accepts the name of a column to join and a set of join conditions.
@@ -1065,7 +1082,7 @@ Alessandro Ranellucci <aar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Alessandro Ranellucci.
+This software is copyright (c) 2017 by Alessandro Ranellucci.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
